@@ -2,19 +2,14 @@
 The "public" properties on the cb module
 
 """
-__version__ = "6.0.0"
+__version__ = "6.0.1"
 from datetime import datetime
 import logging
 from .api_client import (
-    business_combinations,
-    company_disclosures,
-    disclosure_text,
-    document_types,
     enable_backoff,
     html_diff,
     set_credentials,
     set_proxies,
-    tag_contents,
 )
 
 from .disclosures import (
